/**
 * @param {object} context
 * @param {import('@ucanto/interface').Signer} context.storefront
 * @param {import('@ucanto/interface').Signer} context.aggregator
 * @param {import('@ucanto/interface').Signer} context.dealer
 * @param {API.PieceLink} context.aggregate
 * @param {string} context.group
 * @param {API.PieceLink} context.piece
 * @param {import('@ucanto/interface').UnknownLink} context.content
 * @param {import('@ucanto/interface').Block} context.piecesBlock
 * @param {API.InclusionProof} context.inclusionProof
 * @param {API.AggregateAcceptSuccess} context.aggregateAcceptStatus
 */
export function createInvocationsAndReceiptsForDealDataProofChain({ storefront, aggregator, dealer, aggregate, group, piece, content, piecesBlock, inclusionProof, aggregateAcceptStatus, }: {
    storefront: import('@ucanto/interface').Signer;
    aggregator: import('@ucanto/interface').Signer;
    dealer: import('@ucanto/interface').Signer;
    aggregate: API.PieceLink;
    group: string;
    piece: API.PieceLink;
    content: import('@ucanto/interface').UnknownLink;
    piecesBlock: import('@ucanto/interface').Block;
    inclusionProof: API.InclusionProof;
    aggregateAcceptStatus: API.AggregateAcceptSuccess;
}): Promise<{
    invocations: {
        filecoinOfferInvocation: API.UcantoInterface.Invocation<{
            can: "filecoin/offer";
            with: `did:${string}:${string}` & `did:${string}` & API.UcantoInterface.Phantom<{
                protocol: "did:";
            }>;
            nb: import("@ucanto/validator").InferStruct<{
                content: import("@ucanto/core/schema").Schema<API.UcantoInterface.Link<unknown, number, number, 0 | 1>, any>;
                piece: API.PieceLinkSchema;
            }>;
        }>;
        filecoinSubmitInvocation: API.UcantoInterface.Invocation<{
            can: "filecoin/submit";
            with: `did:${string}:${string}` & `did:${string}` & API.UcantoInterface.Phantom<{
                protocol: "did:";
            }>;
            nb: import("@ucanto/validator").InferStruct<{
                content: import("@ucanto/core/schema").Schema<API.UcantoInterface.Link<unknown, number, number, 0 | 1>, any>;
                piece: API.PieceLinkSchema;
            }>;
        }>;
        filecoinAcceptInvocation: API.UcantoInterface.Invocation<{
            can: "filecoin/accept";
            with: `did:${string}:${string}` & `did:${string}` & API.UcantoInterface.Phantom<{
                protocol: "did:";
            }>;
            nb: import("@ucanto/validator").InferStruct<{
                content: import("@ucanto/core/schema").Schema<API.UcantoInterface.Link<unknown, number, number, 0 | 1>, any>;
                piece: API.PieceLinkSchema;
            }>;
        }>;
        pieceOfferInvocation: API.UcantoInterface.Invocation<{
            can: "piece/offer";
            with: `did:${string}:${string}` & `did:${string}` & API.UcantoInterface.Phantom<{
                protocol: "did:";
            }>;
            nb: import("@ucanto/validator").InferStruct<{
                piece: API.PieceLinkSchema;
                group: import("@ucanto/validator").StringSchema<string, unknown>;
            }>;
        }>;
        pieceAcceptInvocation: API.UcantoInterface.Invocation<{
            can: "piece/accept";
            with: `did:${string}:${string}` & `did:${string}` & API.UcantoInterface.Phantom<{
                protocol: "did:";
            }>;
            nb: import("@ucanto/validator").InferStruct<{
                piece: API.PieceLinkSchema;
                group: import("@ucanto/validator").StringSchema<string, unknown>;
            }>;
        }>;
        aggregateOfferInvocation: API.UcantoInterface.Invocation<{
            can: "aggregate/offer";
            with: `did:${string}:${string}` & `did:${string}` & API.UcantoInterface.Phantom<{
                protocol: "did:";
            }>;
            nb: import("@ucanto/validator").InferStruct<{
                aggregate: API.PieceLinkSchema;
                pieces: import("@ucanto/core/schema").Schema<API.UcantoInterface.Link<unknown, number, number, 1>, any>;
            }>;
        }>;
        aggregateAcceptInvocation: API.UcantoInterface.Invocation<{
            can: "aggregate/accept";
            with: `did:${string}:${string}` & `did:${string}` & API.UcantoInterface.Phantom<{
                protocol: "did:";
            }>;
            nb: import("@ucanto/validator").InferStruct<{
                aggregate: API.PieceLinkSchema;
                pieces: import("@ucanto/core/schema").Schema<API.UcantoInterface.Link<unknown, number, number, 0 | 1>, any>;
            }>;
        }>;
    };
    receipts: {
        filecoinOfferReceipt: API.UcantoInterface.Receipt<API.FilecoinOfferSuccess, {}, API.UcantoInterface.Invocation<API.UcantoInterface.Capability<API.UcantoInterface.Ability, `${string}:${string}`, unknown>>, API.UcantoInterface.SigAlg>;
        filecoinSubmitReceipt: API.UcantoInterface.Receipt<API.FilecoinSubmitSuccess, {}, API.UcantoInterface.Invocation<API.UcantoInterface.Capability<API.UcantoInterface.Ability, `${string}:${string}`, unknown>>, API.UcantoInterface.SigAlg>;
        filecoinAcceptReceipt: API.UcantoInterface.Receipt<API.FilecoinAcceptSuccess, {}, API.UcantoInterface.Invocation<API.UcantoInterface.Capability<API.UcantoInterface.Ability, `${string}:${string}`, unknown>>, API.UcantoInterface.SigAlg>;
        pieceOfferReceipt: API.UcantoInterface.Receipt<API.PieceOfferSuccess, {}, API.UcantoInterface.Invocation<API.UcantoInterface.Capability<API.UcantoInterface.Ability, `${string}:${string}`, unknown>>, API.UcantoInterface.SigAlg>;
        pieceAcceptReceipt: API.UcantoInterface.Receipt<API.PieceAcceptSuccess, {}, API.UcantoInterface.Invocation<API.UcantoInterface.Capability<API.UcantoInterface.Ability, `${string}:${string}`, unknown>>, API.UcantoInterface.SigAlg>;
        aggregateOfferReceipt: API.UcantoInterface.Receipt<API.AggregateOfferSuccess, {}, API.UcantoInterface.Invocation<API.UcantoInterface.Capability<API.UcantoInterface.Ability, `${string}:${string}`, unknown>>, API.UcantoInterface.SigAlg>;
        aggregateAcceptReceipt: API.UcantoInterface.Receipt<API.AggregateAcceptSuccess, {}, API.UcantoInterface.Invocation<API.UcantoInterface.Capability<API.UcantoInterface.Ability, `${string}:${string}`, unknown>>, API.UcantoInterface.SigAlg>;
    };
}>;
import * as API from '../../src/types.js';
//# sourceMappingURL=receipts.d.ts.map