/**
 * @typedef {import('../../src/types.js').StorePutError} StorePutError
 * @typedef {import('../../src/types.js').StoreGetError} StoreGetError
 * @typedef {import('../../src/types.js').Pageable} Pageable
 */
/**
 * @template T
 * @typedef {import('../../src/types.js').ListSuccess<T>} ListSuccess
 */
/**
 * @template K
 * @template V
 * @template Q
 * @implements {API.Store<K, V>}
 * @implements {API.UpdatableStore<K, V>}
 * @implements {API.QueryableStore<Q, V>}
 */
export class Store<K, V, Q> implements API.Store<K, V>, API.UpdatableStore<K, V>, API.QueryableStore<Q, V> {
    /**
     * @param {import('./types.js').StoreOptions<K, V> & import('./types.js').UpdatableStoreOptions<K, V> & import('./types.js').QueryableStoreOptions<Q, V> & import('./types.js').ReadableStreamStoreOptions<K, V>} options
     */
    constructor(options: import('./types.js').StoreOptions<K, V> & import('./types.js').UpdatableStoreOptions<K, V> & import('./types.js').QueryableStoreOptions<Q, V> & import('./types.js').ReadableStreamStoreOptions<K, V>);
    /** @type {Set<V>} */
    items: Set<V>;
    getFn: ((items: Set<V>, item: K) => V | undefined) | undefined;
    updateFn: ((items: Set<V>, key: K, item: Partial<V>) => V) | undefined;
    queryFn: ((items: Set<V>, query: Q, options?: API.Pageable | undefined) => API.ListSuccess<V>) | undefined;
    streamFn: ((items: Set<V>, item: K) => ReadableStream<V> | undefined) | undefined;
    /**
     * @param {V} record
     * @returns {Promise<import('@ucanto/interface').Result<{}, StorePutError>>}
     */
    put(record: V): Promise<import('@ucanto/interface').Result<{}, StorePutError>>;
    /**
     *
     * @param {K} item
     * @returns {Promise<import('@ucanto/interface').Result<V, StoreGetError>>}
     */
    get(item: K): Promise<import('@ucanto/interface').Result<V, StoreGetError>>;
    /**
     * @param {K} item
     * @returns {Promise<import('@ucanto/interface').Result<boolean, StoreGetError>>}
     */
    has(item: K): Promise<import('@ucanto/interface').Result<boolean, StoreGetError>>;
    /**
     * @param {Q} search
     * @param {Pageable} [options]
     * @returns {Promise<import('@ucanto/interface').Result<ListSuccess<V>, StoreGetError>>}
     */
    query(search: Q, options?: API.Pageable | undefined): Promise<import('@ucanto/interface').Result<ListSuccess<V>, StoreGetError>>;
    /**
     * @param {K} key
     * @param {Partial<V>} item
     * @returns {Promise<import('@ucanto/interface').Result<V, StoreGetError>>}
     */
    update(key: K, item: Partial<V>): Promise<import('@ucanto/interface').Result<V, StoreGetError>>;
    /**
     * @param {K} item
     * @returns {Promise<import('@ucanto/interface').Result<ReadableStream<V>, StoreGetError>>}
     */
    stream(item: K): Promise<import('@ucanto/interface').Result<ReadableStream<V>, StoreGetError>>;
}
/**
 * @template K
 * @template V
 * @template Q
 * @implements {API.Store<K, V>}
 * @implements {API.UpdatableStore<K, V>}
 * @implements {API.QueryableStore<Q, V>}
 */
export class FailingStore<K, V, Q> implements API.Store<K, V>, API.UpdatableStore<K, V>, API.QueryableStore<Q, V> {
    /**
     * @param {V} record
     */
    put(record: V): Promise<{
        error: StoreOperationFailed;
    }>;
    /**
     * @param {K} item
     * @returns {Promise<import('@ucanto/interface').Result<V, StoreGetError>>}
     */
    get(item: K): Promise<import('@ucanto/interface').Result<V, StoreGetError>>;
    /**
     * @param {K} item
     * @returns {Promise<import('@ucanto/interface').Result<boolean, StoreGetError>>}
     */
    has(item: K): Promise<import('@ucanto/interface').Result<boolean, StoreGetError>>;
    /**
     * @param {Q} search
     * @returns {Promise<import('@ucanto/interface').Result<ListSuccess<V>, StoreGetError>>}
     */
    query(search: Q): Promise<import('@ucanto/interface').Result<ListSuccess<V>, StoreGetError>>;
    /**
     * @param {K} key
     * @param {Partial<V>} item
     * @returns {Promise<import('@ucanto/interface').Result<V, StoreGetError>>}
     */
    update(key: K, item: Partial<V>): Promise<import('@ucanto/interface').Result<V, StoreGetError>>;
}
export type StorePutError = import('../../src/types.js').StorePutError;
export type StoreGetError = import('../../src/types.js').StoreGetError;
export type Pageable = import('../../src/types.js').Pageable;
export type ListSuccess<T> = import('../../src/types.js').ListSuccess<T>;
import * as API from '../../src/types.js';
//# sourceMappingURL=store.d.ts.map